==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkOpenGLTexture.java <==
// java wrapper for vtkOpenGLTexture object
//

package vtk;
import vtk.*;

public class vtkOpenGLTexture extends vtkTexture
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Render_2(vtkRenderer id0);
  public void Render(vtkRenderer id0)
    { Render_2(id0); }

  private native void Load_3(vtkRenderer id0);
  public void Load(vtkRenderer id0)
    { Load_3(id0); }

  private native void PostRender_4(vtkRenderer id0);
  public void PostRender(vtkRenderer id0)
    { PostRender_4(id0); }

  private native void ReleaseGraphicsResources_5(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_5(id0); }

  private native void CopyTexImage_6(int id0,int id1,int id2,int id3);
  public void CopyTexImage(int id0,int id1,int id2,int id3)
    { CopyTexImage_6(id0,id1,id2,id3); }

  private native int GetIsDepthTexture_7();
  public int GetIsDepthTexture()
    { return GetIsDepthTexture_7(); }

  private native void SetIsDepthTexture_8(int id0);
  public void SetIsDepthTexture(int id0)
    { SetIsDepthTexture_8(id0); }

  private native int GetTextureType_9();
  public int GetTextureType()
    { return GetTextureType_9(); }

  private native void SetTextureType_10(int id0);
  public void SetTextureType(int id0)
    { SetTextureType_10(id0); }

  private native int GetTextureUnit_11();
  public int GetTextureUnit()
    { return GetTextureUnit_11(); }

  private native int IsTranslucent_12();
  public int IsTranslucent()
    { return IsTranslucent_12(); }

  public vtkOpenGLTexture() { super(); }

  public vtkOpenGLTexture(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv7h.pkg.tar.xz: vtk/vtkOpenGLTexture.java <==
// java wrapper for vtkOpenGLTexture object
//

package vtk;
import vtk.*;

public class vtkOpenGLTexture extends vtkTexture
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Render_2(vtkRenderer id0);
  public void Render(vtkRenderer id0)
    { Render_2(id0); }

  private native void Load_3(vtkRenderer id0);
  public void Load(vtkRenderer id0)
    { Load_3(id0); }

  private native void PostRender_4(vtkRenderer id0);
  public void PostRender(vtkRenderer id0)
    { PostRender_4(id0); }

  private native void ReleaseGraphicsResources_5(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_5(id0); }

  private native void CopyTexImage_6(int id0,int id1,int id2,int id3);
  public void CopyTexImage(int id0,int id1,int id2,int id3)
    { CopyTexImage_6(id0,id1,id2,id3); }

  private native int GetIsDepthTexture_7();
  public int GetIsDepthTexture()
    { return GetIsDepthTexture_7(); }

  private native void SetIsDepthTexture_8(int id0);
  public void SetIsDepthTexture(int id0)
    { SetIsDepthTexture_8(id0); }

  private native int GetTextureType_9();
  public int GetTextureType()
    { return GetTextureType_9(); }

  private native void SetTextureType_10(int id0);
  public void SetTextureType(int id0)
    { SetTextureType_10(id0); }

  private native int GetTextureUnit_11();
  public int GetTextureUnit()
    { return GetTextureUnit_11(); }

  private native int IsTranslucent_12();
  public int IsTranslucent()
    { return IsTranslucent_12(); }

  public vtkOpenGLTexture() { super(); }

  public vtkOpenGLTexture(long id) { super(id); }
  public native long   VTKInit();

}
